# Copyright (c) 2017 Juliette Foucaut and Doug Binks

# This software is provided 'as-is', without any express or implied
# warranty. In no event will the authors be held liable for any damages
# arising from the use of this software.
# 
# Permission is granted to anyone to use this software for any purpose,
# including commercial applications, and to alter it and redistribute it
# freely, subject to the following restrictions:
# 
# 1. The origin of this software must not be misrepresented; you must not
#    claim that you wrote the original software. If you use this software
#    in a product, an acknowledgment in the product documentation would be
#    appreciated but is not required.
# 2. Altered source versions must be plainly marked as such, and must not be
#    misrepresented as being the original software.
# 3. This notice may not be removed or altered from any source distribution.

# Generated by https://github.com/juliettef/IconFontCppHeaders script
# GenerateIconFontCppHeaders.py for Python from codepoints
# https://github.com/FortAwesome/Font-Awesome/raw/6.x/metadata/icons.yml for
# use with font
# https://github.com/FortAwesome/Font-Awesome/blob/6.x/webfonts/fa-regular-400.ttf,
# https://github.com/FortAwesome/Font-Awesome/blob/6.x/webfonts/fa-solid-900.ttf


# THIS IS AN ALTERED VERSION OF THE ORIGINAL GENERATED PYTHON FILE
# ALTERATIONS ARE LISTED BELOW AS REQUESTED BY THE ABOVE LICENSE
#
# - added license text
# - reformatted "Generated by ..." header
# - renamed class from "IconsFontAwesome6" to "Icon"
# - renamed class member "ICON_MIN" to "RANGE_MIN"
# - renamed class member "ICON_MAX_16" to "RANGE_MAX_16"
# - renamed class member "ICON_MAX" to "RANGE_MAX"
# - removed class member "FONT_ICON_FILE_NAME_FAR = 'fa-regular-400.ttf'"
# - removed class member "FONT_ICON_FILE_NAME_FAS = 'fa-solid-900.ttf'"
# - removed the "ICON" prefix from all digits
# - removed the "ICON_" prefix from all other icons


class Icon:

    ICON_MIN = 0xe005
    ICON_MAX_16 = 0xf8ff
    ICON_MAX = 0xf8ff

    _0 = '\u0030'
    _1 = '\u0031'
    _2 = '\u0032'
    _3 = '\u0033'
    _4 = '\u0034'
    _5 = '\u0035'
    _6 = '\u0036'
    _7 = '\u0037'
    _8 = '\u0038'
    _9 = '\u0039'
    A = '\u0041'
    ADDRESS_BOOK = '\uf2b9'
    ADDRESS_CARD = '\uf2bb'
    ALIGN_CENTER = '\uf037'
    ALIGN_JUSTIFY = '\uf039'
    ALIGN_LEFT = '\uf036'
    ALIGN_RIGHT = '\uf038'
    ANCHOR = '\uf13d'
    ANCHOR_CIRCLE_CHECK = '\ue4aa'
    ANCHOR_CIRCLE_EXCLAMATION = '\ue4ab'
    ANCHOR_CIRCLE_XMARK = '\ue4ac'
    ANCHOR_LOCK = '\ue4ad'
    ANGLE_DOWN = '\uf107'
    ANGLE_LEFT = '\uf104'
    ANGLE_RIGHT = '\uf105'
    ANGLE_UP = '\uf106'
    ANGLES_DOWN = '\uf103'
    ANGLES_LEFT = '\uf100'
    ANGLES_RIGHT = '\uf101'
    ANGLES_UP = '\uf102'
    ANKH = '\uf644'
    APPLE_WHOLE = '\uf5d1'
    ARCHWAY = '\uf557'
    ARROW_DOWN = '\uf063'
    ARROW_DOWN_1_9 = '\uf162'
    ARROW_DOWN_9_1 = '\uf886'
    ARROW_DOWN_A_Z = '\uf15d'
    ARROW_DOWN_LONG = '\uf175'
    ARROW_DOWN_SHORT_WIDE = '\uf884'
    ARROW_DOWN_UP_ACROSS_LINE = '\ue4af'
    ARROW_DOWN_UP_LOCK = '\ue4b0'
    ARROW_DOWN_WIDE_SHORT = '\uf160'
    ARROW_DOWN_Z_A = '\uf881'
    ARROW_LEFT = '\uf060'
    ARROW_LEFT_LONG = '\uf177'
    ARROW_POINTER = '\uf245'
    ARROW_RIGHT = '\uf061'
    ARROW_RIGHT_ARROW_LEFT = '\uf0ec'
    ARROW_RIGHT_FROM_BRACKET = '\uf08b'
    ARROW_RIGHT_LONG = '\uf178'
    ARROW_RIGHT_TO_BRACKET = '\uf090'
    ARROW_RIGHT_TO_CITY = '\ue4b3'
    ARROW_ROTATE_LEFT = '\uf0e2'
    ARROW_ROTATE_RIGHT = '\uf01e'
    ARROW_TREND_DOWN = '\ue097'
    ARROW_TREND_UP = '\ue098'
    ARROW_TURN_DOWN = '\uf149'
    ARROW_TURN_UP = '\uf148'
    ARROW_UP = '\uf062'
    ARROW_UP_1_9 = '\uf163'
    ARROW_UP_9_1 = '\uf887'
    ARROW_UP_A_Z = '\uf15e'
    ARROW_UP_FROM_BRACKET = '\ue09a'
    ARROW_UP_FROM_GROUND_WATER = '\ue4b5'
    ARROW_UP_FROM_WATER_PUMP = '\ue4b6'
    ARROW_UP_LONG = '\uf176'
    ARROW_UP_RIGHT_DOTS = '\ue4b7'
    ARROW_UP_RIGHT_FROM_SQUARE = '\uf08e'
    ARROW_UP_SHORT_WIDE = '\uf885'
    ARROW_UP_WIDE_SHORT = '\uf161'
    ARROW_UP_Z_A = '\uf882'
    ARROWS_DOWN_TO_LINE = '\ue4b8'
    ARROWS_DOWN_TO_PEOPLE = '\ue4b9'
    ARROWS_LEFT_RIGHT = '\uf07e'
    ARROWS_LEFT_RIGHT_TO_LINE = '\ue4ba'
    ARROWS_ROTATE = '\uf021'
    ARROWS_SPIN = '\ue4bb'
    ARROWS_SPLIT_UP_AND_LEFT = '\ue4bc'
    ARROWS_TO_CIRCLE = '\ue4bd'
    ARROWS_TO_DOT = '\ue4be'
    ARROWS_TO_EYE = '\ue4bf'
    ARROWS_TURN_RIGHT = '\ue4c0'
    ARROWS_TURN_TO_DOTS = '\ue4c1'
    ARROWS_UP_DOWN = '\uf07d'
    ARROWS_UP_DOWN_LEFT_RIGHT = '\uf047'
    ARROWS_UP_TO_LINE = '\ue4c2'
    ASTERISK = '\u002a'
    AT = '\u0040'
    ATOM = '\uf5d2'
    AUDIO_DESCRIPTION = '\uf29e'
    AUSTRAL_SIGN = '\ue0a9'
    AWARD = '\uf559'
    B = '\u0042'
    BABY = '\uf77c'
    BABY_CARRIAGE = '\uf77d'
    BACKWARD = '\uf04a'
    BACKWARD_FAST = '\uf049'
    BACKWARD_STEP = '\uf048'
    BACON = '\uf7e5'
    BACTERIA = '\ue059'
    BACTERIUM = '\ue05a'
    BAG_SHOPPING = '\uf290'
    BAHAI = '\uf666'
    BAHT_SIGN = '\ue0ac'
    BAN = '\uf05e'
    BAN_SMOKING = '\uf54d'
    BANDAGE = '\uf462'
    BANGLADESHI_TAKA_SIGN = '\ue2e6'
    BARCODE = '\uf02a'
    BARS = '\uf0c9'
    BARS_PROGRESS = '\uf828'
    BARS_STAGGERED = '\uf550'
    BASEBALL = '\uf433'
    BASEBALL_BAT_BALL = '\uf432'
    BASKET_SHOPPING = '\uf291'
    BASKETBALL = '\uf434'
    BATH = '\uf2cd'
    BATTERY_EMPTY = '\uf244'
    BATTERY_FULL = '\uf240'
    BATTERY_HALF = '\uf242'
    BATTERY_QUARTER = '\uf243'
    BATTERY_THREE_QUARTERS = '\uf241'
    BED = '\uf236'
    BED_PULSE = '\uf487'
    BEER_MUG_EMPTY = '\uf0fc'
    BELL = '\uf0f3'
    BELL_CONCIERGE = '\uf562'
    BELL_SLASH = '\uf1f6'
    BEZIER_CURVE = '\uf55b'
    BICYCLE = '\uf206'
    BINOCULARS = '\uf1e5'
    BIOHAZARD = '\uf780'
    BITCOIN_SIGN = '\ue0b4'
    BLENDER = '\uf517'
    BLENDER_PHONE = '\uf6b6'
    BLOG = '\uf781'
    BOLD = '\uf032'
    BOLT = '\uf0e7'
    BOLT_LIGHTNING = '\ue0b7'
    BOMB = '\uf1e2'
    BONE = '\uf5d7'
    BONG = '\uf55c'
    BOOK = '\uf02d'
    BOOK_ATLAS = '\uf558'
    BOOK_BIBLE = '\uf647'
    BOOK_BOOKMARK = '\ue0bb'
    BOOK_JOURNAL_WHILLS = '\uf66a'
    BOOK_MEDICAL = '\uf7e6'
    BOOK_OPEN = '\uf518'
    BOOK_OPEN_READER = '\uf5da'
    BOOK_QURAN = '\uf687'
    BOOK_SKULL = '\uf6b7'
    BOOK_TANAKH = '\uf827'
    BOOKMARK = '\uf02e'
    BORDER_ALL = '\uf84c'
    BORDER_NONE = '\uf850'
    BORDER_TOP_LEFT = '\uf853'
    BORE_HOLE = '\ue4c3'
    BOTTLE_DROPLET = '\ue4c4'
    BOTTLE_WATER = '\ue4c5'
    BOWL_FOOD = '\ue4c6'
    BOWL_RICE = '\ue2eb'
    BOWLING_BALL = '\uf436'
    BOX = '\uf466'
    BOX_ARCHIVE = '\uf187'
    BOX_OPEN = '\uf49e'
    BOX_TISSUE = '\ue05b'
    BOXES_PACKING = '\ue4c7'
    BOXES_STACKED = '\uf468'
    BRAILLE = '\uf2a1'
    BRAIN = '\uf5dc'
    BRAZILIAN_REAL_SIGN = '\ue46c'
    BREAD_SLICE = '\uf7ec'
    BRIDGE = '\ue4c8'
    BRIDGE_CIRCLE_CHECK = '\ue4c9'
    BRIDGE_CIRCLE_EXCLAMATION = '\ue4ca'
    BRIDGE_CIRCLE_XMARK = '\ue4cb'
    BRIDGE_LOCK = '\ue4cc'
    BRIDGE_WATER = '\ue4ce'
    BRIEFCASE = '\uf0b1'
    BRIEFCASE_MEDICAL = '\uf469'
    BROOM = '\uf51a'
    BROOM_BALL = '\uf458'
    BRUSH = '\uf55d'
    BUCKET = '\ue4cf'
    BUG = '\uf188'
    BUG_SLASH = '\ue490'
    BUGS = '\ue4d0'
    BUILDING = '\uf1ad'
    BUILDING_CIRCLE_ARROW_RIGHT = '\ue4d1'
    BUILDING_CIRCLE_CHECK = '\ue4d2'
    BUILDING_CIRCLE_EXCLAMATION = '\ue4d3'
    BUILDING_CIRCLE_XMARK = '\ue4d4'
    BUILDING_COLUMNS = '\uf19c'
    BUILDING_FLAG = '\ue4d5'
    BUILDING_LOCK = '\ue4d6'
    BUILDING_NGO = '\ue4d7'
    BUILDING_SHIELD = '\ue4d8'
    BUILDING_UN = '\ue4d9'
    BUILDING_USER = '\ue4da'
    BUILDING_WHEAT = '\ue4db'
    BULLHORN = '\uf0a1'
    BULLSEYE = '\uf140'
    BURGER = '\uf805'
    BURST = '\ue4dc'
    BUS = '\uf207'
    BUS_SIMPLE = '\uf55e'
    BUSINESS_TIME = '\uf64a'
    C = '\u0043'
    CABLE_CAR = '\uf7da'
    CAKE_CANDLES = '\uf1fd'
    CALCULATOR = '\uf1ec'
    CALENDAR = '\uf133'
    CALENDAR_CHECK = '\uf274'
    CALENDAR_DAY = '\uf783'
    CALENDAR_DAYS = '\uf073'
    CALENDAR_MINUS = '\uf272'
    CALENDAR_PLUS = '\uf271'
    CALENDAR_WEEK = '\uf784'
    CALENDAR_XMARK = '\uf273'
    CAMERA = '\uf030'
    CAMERA_RETRO = '\uf083'
    CAMERA_ROTATE = '\ue0d8'
    CAMPGROUND = '\uf6bb'
    CANDY_CANE = '\uf786'
    CANNABIS = '\uf55f'
    CAPSULES = '\uf46b'
    CAR = '\uf1b9'
    CAR_BATTERY = '\uf5df'
    CAR_BURST = '\uf5e1'
    CAR_ON = '\ue4dd'
    CAR_REAR = '\uf5de'
    CAR_SIDE = '\uf5e4'
    CAR_TUNNEL = '\ue4de'
    CARAVAN = '\uf8ff'
    CARET_DOWN = '\uf0d7'
    CARET_LEFT = '\uf0d9'
    CARET_RIGHT = '\uf0da'
    CARET_UP = '\uf0d8'
    CARROT = '\uf787'
    CART_ARROW_DOWN = '\uf218'
    CART_FLATBED = '\uf474'
    CART_FLATBED_SUITCASE = '\uf59d'
    CART_PLUS = '\uf217'
    CART_SHOPPING = '\uf07a'
    CASH_REGISTER = '\uf788'
    CAT = '\uf6be'
    CEDI_SIGN = '\ue0df'
    CENT_SIGN = '\ue3f5'
    CERTIFICATE = '\uf0a3'
    CHAIR = '\uf6c0'
    CHALKBOARD = '\uf51b'
    CHALKBOARD_USER = '\uf51c'
    CHAMPAGNE_GLASSES = '\uf79f'
    CHARGING_STATION = '\uf5e7'
    CHART_AREA = '\uf1fe'
    CHART_BAR = '\uf080'
    CHART_COLUMN = '\ue0e3'
    CHART_GANTT = '\ue0e4'
    CHART_LINE = '\uf201'
    CHART_PIE = '\uf200'
    CHART_SIMPLE = '\ue473'
    CHECK = '\uf00c'
    CHECK_DOUBLE = '\uf560'
    CHECK_TO_SLOT = '\uf772'
    CHEESE = '\uf7ef'
    CHESS = '\uf439'
    CHESS_BISHOP = '\uf43a'
    CHESS_BOARD = '\uf43c'
    CHESS_KING = '\uf43f'
    CHESS_KNIGHT = '\uf441'
    CHESS_PAWN = '\uf443'
    CHESS_QUEEN = '\uf445'
    CHESS_ROOK = '\uf447'
    CHEVRON_DOWN = '\uf078'
    CHEVRON_LEFT = '\uf053'
    CHEVRON_RIGHT = '\uf054'
    CHEVRON_UP = '\uf077'
    CHILD = '\uf1ae'
    CHILD_COMBATANT = '\ue4e0'
    CHILD_DRESS = '\ue59c'
    CHILD_REACHING = '\ue59d'
    CHILDREN = '\ue4e1'
    CHURCH = '\uf51d'
    CIRCLE = '\uf111'
    CIRCLE_ARROW_DOWN = '\uf0ab'
    CIRCLE_ARROW_LEFT = '\uf0a8'
    CIRCLE_ARROW_RIGHT = '\uf0a9'
    CIRCLE_ARROW_UP = '\uf0aa'
    CIRCLE_CHECK = '\uf058'
    CIRCLE_CHEVRON_DOWN = '\uf13a'
    CIRCLE_CHEVRON_LEFT = '\uf137'
    CIRCLE_CHEVRON_RIGHT = '\uf138'
    CIRCLE_CHEVRON_UP = '\uf139'
    CIRCLE_DOLLAR_TO_SLOT = '\uf4b9'
    CIRCLE_DOT = '\uf192'
    CIRCLE_DOWN = '\uf358'
    CIRCLE_EXCLAMATION = '\uf06a'
    CIRCLE_H = '\uf47e'
    CIRCLE_HALF_STROKE = '\uf042'
    CIRCLE_INFO = '\uf05a'
    CIRCLE_LEFT = '\uf359'
    CIRCLE_MINUS = '\uf056'
    CIRCLE_NODES = '\ue4e2'
    CIRCLE_NOTCH = '\uf1ce'
    CIRCLE_PAUSE = '\uf28b'
    CIRCLE_PLAY = '\uf144'
    CIRCLE_PLUS = '\uf055'
    CIRCLE_QUESTION = '\uf059'
    CIRCLE_RADIATION = '\uf7ba'
    CIRCLE_RIGHT = '\uf35a'
    CIRCLE_STOP = '\uf28d'
    CIRCLE_UP = '\uf35b'
    CIRCLE_USER = '\uf2bd'
    CIRCLE_XMARK = '\uf057'
    CITY = '\uf64f'
    CLAPPERBOARD = '\ue131'
    CLIPBOARD = '\uf328'
    CLIPBOARD_CHECK = '\uf46c'
    CLIPBOARD_LIST = '\uf46d'
    CLIPBOARD_QUESTION = '\ue4e3'
    CLIPBOARD_USER = '\uf7f3'
    CLOCK = '\uf017'
    CLOCK_ROTATE_LEFT = '\uf1da'
    CLONE = '\uf24d'
    CLOSED_CAPTIONING = '\uf20a'
    CLOUD = '\uf0c2'
    CLOUD_ARROW_DOWN = '\uf0ed'
    CLOUD_ARROW_UP = '\uf0ee'
    CLOUD_BOLT = '\uf76c'
    CLOUD_MEATBALL = '\uf73b'
    CLOUD_MOON = '\uf6c3'
    CLOUD_MOON_RAIN = '\uf73c'
    CLOUD_RAIN = '\uf73d'
    CLOUD_SHOWERS_HEAVY = '\uf740'
    CLOUD_SHOWERS_WATER = '\ue4e4'
    CLOUD_SUN = '\uf6c4'
    CLOUD_SUN_RAIN = '\uf743'
    CLOVER = '\ue139'
    CODE = '\uf121'
    CODE_BRANCH = '\uf126'
    CODE_COMMIT = '\uf386'
    CODE_COMPARE = '\ue13a'
    CODE_FORK = '\ue13b'
    CODE_MERGE = '\uf387'
    CODE_PULL_REQUEST = '\ue13c'
    COINS = '\uf51e'
    COLON_SIGN = '\ue140'
    COMMENT = '\uf075'
    COMMENT_DOLLAR = '\uf651'
    COMMENT_DOTS = '\uf4ad'
    COMMENT_MEDICAL = '\uf7f5'
    COMMENT_SLASH = '\uf4b3'
    COMMENT_SMS = '\uf7cd'
    COMMENTS = '\uf086'
    COMMENTS_DOLLAR = '\uf653'
    COMPACT_DISC = '\uf51f'
    COMPASS = '\uf14e'
    COMPASS_DRAFTING = '\uf568'
    COMPRESS = '\uf066'
    COMPUTER = '\ue4e5'
    COMPUTER_MOUSE = '\uf8cc'
    COOKIE = '\uf563'
    COOKIE_BITE = '\uf564'
    COPY = '\uf0c5'
    COPYRIGHT = '\uf1f9'
    COUCH = '\uf4b8'
    COW = '\uf6c8'
    CREDIT_CARD = '\uf09d'
    CROP = '\uf125'
    CROP_SIMPLE = '\uf565'
    CROSS = '\uf654'
    CROSSHAIRS = '\uf05b'
    CROW = '\uf520'
    CROWN = '\uf521'
    CRUTCH = '\uf7f7'
    CRUZEIRO_SIGN = '\ue152'
    CUBE = '\uf1b2'
    CUBES = '\uf1b3'
    CUBES_STACKED = '\ue4e6'
    D = '\u0044'
    DATABASE = '\uf1c0'
    DELETE_LEFT = '\uf55a'
    DEMOCRAT = '\uf747'
    DESKTOP = '\uf390'
    DHARMACHAKRA = '\uf655'
    DIAGRAM_NEXT = '\ue476'
    DIAGRAM_PREDECESSOR = '\ue477'
    DIAGRAM_PROJECT = '\uf542'
    DIAGRAM_SUCCESSOR = '\ue47a'
    DIAMOND = '\uf219'
    DIAMOND_TURN_RIGHT = '\uf5eb'
    DICE = '\uf522'
    DICE_D20 = '\uf6cf'
    DICE_D6 = '\uf6d1'
    DICE_FIVE = '\uf523'
    DICE_FOUR = '\uf524'
    DICE_ONE = '\uf525'
    DICE_SIX = '\uf526'
    DICE_THREE = '\uf527'
    DICE_TWO = '\uf528'
    DISEASE = '\uf7fa'
    DISPLAY = '\ue163'
    DIVIDE = '\uf529'
    DNA = '\uf471'
    DOG = '\uf6d3'
    DOLLAR_SIGN = '\u0024'
    DOLLY = '\uf472'
    DONG_SIGN = '\ue169'
    DOOR_CLOSED = '\uf52a'
    DOOR_OPEN = '\uf52b'
    DOVE = '\uf4ba'
    DOWN_LEFT_AND_UP_RIGHT_TO_CENTER = '\uf422'
    DOWN_LONG = '\uf309'
    DOWNLOAD = '\uf019'
    DRAGON = '\uf6d5'
    DRAW_POLYGON = '\uf5ee'
    DROPLET = '\uf043'
    DROPLET_SLASH = '\uf5c7'
    DRUM = '\uf569'
    DRUM_STEELPAN = '\uf56a'
    DRUMSTICK_BITE = '\uf6d7'
    DUMBBELL = '\uf44b'
    DUMPSTER = '\uf793'
    DUMPSTER_FIRE = '\uf794'
    DUNGEON = '\uf6d9'
    E = '\u0045'
    EAR_DEAF = '\uf2a4'
    EAR_LISTEN = '\uf2a2'
    EARTH_AFRICA = '\uf57c'
    EARTH_AMERICAS = '\uf57d'
    EARTH_ASIA = '\uf57e'
    EARTH_EUROPE = '\uf7a2'
    EARTH_OCEANIA = '\ue47b'
    EGG = '\uf7fb'
    EJECT = '\uf052'
    ELEVATOR = '\ue16d'
    ELLIPSIS = '\uf141'
    ELLIPSIS_VERTICAL = '\uf142'
    ENVELOPE = '\uf0e0'
    ENVELOPE_CIRCLE_CHECK = '\ue4e8'
    ENVELOPE_OPEN = '\uf2b6'
    ENVELOPE_OPEN_TEXT = '\uf658'
    ENVELOPES_BULK = '\uf674'
    EQUALS = '\u003d'
    ERASER = '\uf12d'
    ETHERNET = '\uf796'
    EURO_SIGN = '\uf153'
    EXCLAMATION = '\u0021'
    EXPAND = '\uf065'
    EXPLOSION = '\ue4e9'
    EYE = '\uf06e'
    EYE_DROPPER = '\uf1fb'
    EYE_LOW_VISION = '\uf2a8'
    EYE_SLASH = '\uf070'
    F = '\u0046'
    FACE_ANGRY = '\uf556'
    FACE_DIZZY = '\uf567'
    FACE_FLUSHED = '\uf579'
    FACE_FROWN = '\uf119'
    FACE_FROWN_OPEN = '\uf57a'
    FACE_GRIMACE = '\uf57f'
    FACE_GRIN = '\uf580'
    FACE_GRIN_BEAM = '\uf582'
    FACE_GRIN_BEAM_SWEAT = '\uf583'
    FACE_GRIN_HEARTS = '\uf584'
    FACE_GRIN_SQUINT = '\uf585'
    FACE_GRIN_SQUINT_TEARS = '\uf586'
    FACE_GRIN_STARS = '\uf587'
    FACE_GRIN_TEARS = '\uf588'
    FACE_GRIN_TONGUE = '\uf589'
    FACE_GRIN_TONGUE_SQUINT = '\uf58a'
    FACE_GRIN_TONGUE_WINK = '\uf58b'
    FACE_GRIN_WIDE = '\uf581'
    FACE_GRIN_WINK = '\uf58c'
    FACE_KISS = '\uf596'
    FACE_KISS_BEAM = '\uf597'
    FACE_KISS_WINK_HEART = '\uf598'
    FACE_LAUGH = '\uf599'
    FACE_LAUGH_BEAM = '\uf59a'
    FACE_LAUGH_SQUINT = '\uf59b'
    FACE_LAUGH_WINK = '\uf59c'
    FACE_MEH = '\uf11a'
    FACE_MEH_BLANK = '\uf5a4'
    FACE_ROLLING_EYES = '\uf5a5'
    FACE_SAD_CRY = '\uf5b3'
    FACE_SAD_TEAR = '\uf5b4'
    FACE_SMILE = '\uf118'
    FACE_SMILE_BEAM = '\uf5b8'
    FACE_SMILE_WINK = '\uf4da'
    FACE_SURPRISE = '\uf5c2'
    FACE_TIRED = '\uf5c8'
    FAN = '\uf863'
    FAUCET = '\ue005'
    FAUCET_DRIP = '\ue006'
    FAX = '\uf1ac'
    FEATHER = '\uf52d'
    FEATHER_POINTED = '\uf56b'
    FERRY = '\ue4ea'
    FILE = '\uf15b'
    FILE_ARROW_DOWN = '\uf56d'
    FILE_ARROW_UP = '\uf574'
    FILE_AUDIO = '\uf1c7'
    FILE_CIRCLE_CHECK = '\ue5a0'
    FILE_CIRCLE_EXCLAMATION = '\ue4eb'
    FILE_CIRCLE_MINUS = '\ue4ed'
    FILE_CIRCLE_PLUS = '\ue494'
    FILE_CIRCLE_QUESTION = '\ue4ef'
    FILE_CIRCLE_XMARK = '\ue5a1'
    FILE_CODE = '\uf1c9'
    FILE_CONTRACT = '\uf56c'
    FILE_CSV = '\uf6dd'
    FILE_EXCEL = '\uf1c3'
    FILE_EXPORT = '\uf56e'
    FILE_IMAGE = '\uf1c5'
    FILE_IMPORT = '\uf56f'
    FILE_INVOICE = '\uf570'
    FILE_INVOICE_DOLLAR = '\uf571'
    FILE_LINES = '\uf15c'
    FILE_MEDICAL = '\uf477'
    FILE_PDF = '\uf1c1'
    FILE_PEN = '\uf31c'
    FILE_POWERPOINT = '\uf1c4'
    FILE_PRESCRIPTION = '\uf572'
    FILE_SHIELD = '\ue4f0'
    FILE_SIGNATURE = '\uf573'
    FILE_VIDEO = '\uf1c8'
    FILE_WAVEFORM = '\uf478'
    FILE_WORD = '\uf1c2'
    FILE_ZIPPER = '\uf1c6'
    FILL = '\uf575'
    FILL_DRIP = '\uf576'
    FILM = '\uf008'
    FILTER = '\uf0b0'
    FILTER_CIRCLE_DOLLAR = '\uf662'
    FILTER_CIRCLE_XMARK = '\ue17b'
    FINGERPRINT = '\uf577'
    FIRE = '\uf06d'
    FIRE_BURNER = '\ue4f1'
    FIRE_EXTINGUISHER = '\uf134'
    FIRE_FLAME_CURVED = '\uf7e4'
    FIRE_FLAME_SIMPLE = '\uf46a'
    FISH = '\uf578'
    FISH_FINS = '\ue4f2'
    FLAG = '\uf024'
    FLAG_CHECKERED = '\uf11e'
    FLAG_USA = '\uf74d'
    FLASK = '\uf0c3'
    FLASK_VIAL = '\ue4f3'
    FLOPPY_DISK = '\uf0c7'
    FLORIN_SIGN = '\ue184'
    FOLDER = '\uf07b'
    FOLDER_CLOSED = '\ue185'
    FOLDER_MINUS = '\uf65d'
    FOLDER_OPEN = '\uf07c'
    FOLDER_PLUS = '\uf65e'
    FOLDER_TREE = '\uf802'
    FONT = '\uf031'
    FONT_AWESOME = '\uf2b4'
    FOOTBALL = '\uf44e'
    FORWARD = '\uf04e'
    FORWARD_FAST = '\uf050'
    FORWARD_STEP = '\uf051'
    FRANC_SIGN = '\ue18f'
    FROG = '\uf52e'
    FUTBOL = '\uf1e3'
    G = '\u0047'
    GAMEPAD = '\uf11b'
    GAS_PUMP = '\uf52f'
    GAUGE = '\uf624'
    GAUGE_HIGH = '\uf625'
    GAUGE_SIMPLE = '\uf629'
    GAUGE_SIMPLE_HIGH = '\uf62a'
    GAVEL = '\uf0e3'
    GEAR = '\uf013'
    GEARS = '\uf085'
    GEM = '\uf3a5'
    GENDERLESS = '\uf22d'
    GHOST = '\uf6e2'
    GIFT = '\uf06b'
    GIFTS = '\uf79c'
    GLASS_WATER = '\ue4f4'
    GLASS_WATER_DROPLET = '\ue4f5'
    GLASSES = '\uf530'
    GLOBE = '\uf0ac'
    GOLF_BALL_TEE = '\uf450'
    GOPURAM = '\uf664'
    GRADUATION_CAP = '\uf19d'
    GREATER_THAN = '\u003e'
    GREATER_THAN_EQUAL = '\uf532'
    GRIP = '\uf58d'
    GRIP_LINES = '\uf7a4'
    GRIP_LINES_VERTICAL = '\uf7a5'
    GRIP_VERTICAL = '\uf58e'
    GROUP_ARROWS_ROTATE = '\ue4f6'
    GUARANI_SIGN = '\ue19a'
    GUITAR = '\uf7a6'
    GUN = '\ue19b'
    H = '\u0048'
    HAMMER = '\uf6e3'
    HAMSA = '\uf665'
    HAND = '\uf256'
    HAND_BACK_FIST = '\uf255'
    HAND_DOTS = '\uf461'
    HAND_FIST = '\uf6de'
    HAND_HOLDING = '\uf4bd'
    HAND_HOLDING_DOLLAR = '\uf4c0'
    HAND_HOLDING_DROPLET = '\uf4c1'
    HAND_HOLDING_HAND = '\ue4f7'
    HAND_HOLDING_HEART = '\uf4be'
    HAND_HOLDING_MEDICAL = '\ue05c'
    HAND_LIZARD = '\uf258'
    HAND_MIDDLE_FINGER = '\uf806'
    HAND_PEACE = '\uf25b'
    HAND_POINT_DOWN = '\uf0a7'
    HAND_POINT_LEFT = '\uf0a5'
    HAND_POINT_RIGHT = '\uf0a4'
    HAND_POINT_UP = '\uf0a6'
    HAND_POINTER = '\uf25a'
    HAND_SCISSORS = '\uf257'
    HAND_SPARKLES = '\ue05d'
    HAND_SPOCK = '\uf259'
    HANDCUFFS = '\ue4f8'
    HANDS = '\uf2a7'
    HANDS_ASL_INTERPRETING = '\uf2a3'
    HANDS_BOUND = '\ue4f9'
    HANDS_BUBBLES = '\ue05e'
    HANDS_CLAPPING = '\ue1a8'
    HANDS_HOLDING = '\uf4c2'
    HANDS_HOLDING_CHILD = '\ue4fa'
    HANDS_HOLDING_CIRCLE = '\ue4fb'
    HANDS_PRAYING = '\uf684'
    HANDSHAKE = '\uf2b5'
    HANDSHAKE_ANGLE = '\uf4c4'
    HANDSHAKE_SIMPLE = '\uf4c6'
    HANDSHAKE_SIMPLE_SLASH = '\ue05f'
    HANDSHAKE_SLASH = '\ue060'
    HANUKIAH = '\uf6e6'
    HARD_DRIVE = '\uf0a0'
    HASHTAG = '\u0023'
    HAT_COWBOY = '\uf8c0'
    HAT_COWBOY_SIDE = '\uf8c1'
    HAT_WIZARD = '\uf6e8'
    HEAD_SIDE_COUGH = '\ue061'
    HEAD_SIDE_COUGH_SLASH = '\ue062'
    HEAD_SIDE_MASK = '\ue063'
    HEAD_SIDE_VIRUS = '\ue064'
    HEADING = '\uf1dc'
    HEADPHONES = '\uf025'
    HEADPHONES_SIMPLE = '\uf58f'
    HEADSET = '\uf590'
    HEART = '\uf004'
    HEART_CIRCLE_BOLT = '\ue4fc'
    HEART_CIRCLE_CHECK = '\ue4fd'
    HEART_CIRCLE_EXCLAMATION = '\ue4fe'
    HEART_CIRCLE_MINUS = '\ue4ff'
    HEART_CIRCLE_PLUS = '\ue500'
    HEART_CIRCLE_XMARK = '\ue501'
    HEART_CRACK = '\uf7a9'
    HEART_PULSE = '\uf21e'
    HELICOPTER = '\uf533'
    HELICOPTER_SYMBOL = '\ue502'
    HELMET_SAFETY = '\uf807'
    HELMET_UN = '\ue503'
    HIGHLIGHTER = '\uf591'
    HILL_AVALANCHE = '\ue507'
    HILL_ROCKSLIDE = '\ue508'
    HIPPO = '\uf6ed'
    HOCKEY_PUCK = '\uf453'
    HOLLY_BERRY = '\uf7aa'
    HORSE = '\uf6f0'
    HORSE_HEAD = '\uf7ab'
    HOSPITAL = '\uf0f8'
    HOSPITAL_USER = '\uf80d'
    HOT_TUB_PERSON = '\uf593'
    HOTDOG = '\uf80f'
    HOTEL = '\uf594'
    HOURGLASS = '\uf254'
    HOURGLASS_END = '\uf253'
    HOURGLASS_HALF = '\uf252'
    HOURGLASS_START = '\uf251'
    HOUSE = '\uf015'
    HOUSE_CHIMNEY = '\ue3af'
    HOUSE_CHIMNEY_CRACK = '\uf6f1'
    HOUSE_CHIMNEY_MEDICAL = '\uf7f2'
    HOUSE_CHIMNEY_USER = '\ue065'
    HOUSE_CHIMNEY_WINDOW = '\ue00d'
    HOUSE_CIRCLE_CHECK = '\ue509'
    HOUSE_CIRCLE_EXCLAMATION = '\ue50a'
    HOUSE_CIRCLE_XMARK = '\ue50b'
    HOUSE_CRACK = '\ue3b1'
    HOUSE_FIRE = '\ue50c'
    HOUSE_FLAG = '\ue50d'
    HOUSE_FLOOD_WATER = '\ue50e'
    HOUSE_FLOOD_WATER_CIRCLE_ARROW_RIGHT = '\ue50f'
    HOUSE_LAPTOP = '\ue066'
    HOUSE_LOCK = '\ue510'
    HOUSE_MEDICAL = '\ue3b2'
    HOUSE_MEDICAL_CIRCLE_CHECK = '\ue511'
    HOUSE_MEDICAL_CIRCLE_EXCLAMATION = '\ue512'
    HOUSE_MEDICAL_CIRCLE_XMARK = '\ue513'
    HOUSE_MEDICAL_FLAG = '\ue514'
    HOUSE_SIGNAL = '\ue012'
    HOUSE_TSUNAMI = '\ue515'
    HOUSE_USER = '\ue1b0'
    HRYVNIA_SIGN = '\uf6f2'
    HURRICANE = '\uf751'
    I = '\u0049'
    I_CURSOR = '\uf246'
    ICE_CREAM = '\uf810'
    ICICLES = '\uf7ad'
    ICONS = '\uf86d'
    ID_BADGE = '\uf2c1'
    ID_CARD = '\uf2c2'
    ID_CARD_CLIP = '\uf47f'
    IGLOO = '\uf7ae'
    IMAGE = '\uf03e'
    IMAGE_PORTRAIT = '\uf3e0'
    IMAGES = '\uf302'
    INBOX = '\uf01c'
    INDENT = '\uf03c'
    INDIAN_RUPEE_SIGN = '\ue1bc'
    INDUSTRY = '\uf275'
    INFINITY = '\uf534'
    INFO = '\uf129'
    ITALIC = '\uf033'
    J = '\u004a'
    JAR = '\ue516'
    JAR_WHEAT = '\ue517'
    JEDI = '\uf669'
    JET_FIGHTER = '\uf0fb'
    JET_FIGHTER_UP = '\ue518'
    JOINT = '\uf595'
    JUG_DETERGENT = '\ue519'
    K = '\u004b'
    KAABA = '\uf66b'
    KEY = '\uf084'
    KEYBOARD = '\uf11c'
    KHANDA = '\uf66d'
    KIP_SIGN = '\ue1c4'
    KIT_MEDICAL = '\uf479'
    KITCHEN_SET = '\ue51a'
    KIWI_BIRD = '\uf535'
    L = '\u004c'
    LAND_MINE_ON = '\ue51b'
    LANDMARK = '\uf66f'
    LANDMARK_DOME = '\uf752'
    LANDMARK_FLAG = '\ue51c'
    LANGUAGE = '\uf1ab'
    LAPTOP = '\uf109'
    LAPTOP_CODE = '\uf5fc'
    LAPTOP_FILE = '\ue51d'
    LAPTOP_MEDICAL = '\uf812'
    LARI_SIGN = '\ue1c8'
    LAYER_GROUP = '\uf5fd'
    LEAF = '\uf06c'
    LEFT_LONG = '\uf30a'
    LEFT_RIGHT = '\uf337'
    LEMON = '\uf094'
    LESS_THAN = '\u003c'
    LESS_THAN_EQUAL = '\uf537'
    LIFE_RING = '\uf1cd'
    LIGHTBULB = '\uf0eb'
    LINES_LEANING = '\ue51e'
    LINK = '\uf0c1'
    LINK_SLASH = '\uf127'
    LIRA_SIGN = '\uf195'
    LIST = '\uf03a'
    LIST_CHECK = '\uf0ae'
    LIST_OL = '\uf0cb'
    LIST_UL = '\uf0ca'
    LITECOIN_SIGN = '\ue1d3'
    LOCATION_ARROW = '\uf124'
    LOCATION_CROSSHAIRS = '\uf601'
    LOCATION_DOT = '\uf3c5'
    LOCATION_PIN = '\uf041'
    LOCATION_PIN_LOCK = '\ue51f'
    LOCK = '\uf023'
    LOCK_OPEN = '\uf3c1'
    LOCUST = '\ue520'
    LUNGS = '\uf604'
    LUNGS_VIRUS = '\ue067'
    M = '\u004d'
    MAGNET = '\uf076'
    MAGNIFYING_GLASS = '\uf002'
    MAGNIFYING_GLASS_ARROW_RIGHT = '\ue521'
    MAGNIFYING_GLASS_CHART = '\ue522'
    MAGNIFYING_GLASS_DOLLAR = '\uf688'
    MAGNIFYING_GLASS_LOCATION = '\uf689'
    MAGNIFYING_GLASS_MINUS = '\uf010'
    MAGNIFYING_GLASS_PLUS = '\uf00e'
    MANAT_SIGN = '\ue1d5'
    MAP = '\uf279'
    MAP_LOCATION = '\uf59f'
    MAP_LOCATION_DOT = '\uf5a0'
    MAP_PIN = '\uf276'
    MARKER = '\uf5a1'
    MARS = '\uf222'
    MARS_AND_VENUS = '\uf224'
    MARS_AND_VENUS_BURST = '\ue523'
    MARS_DOUBLE = '\uf227'
    MARS_STROKE = '\uf229'
    MARS_STROKE_RIGHT = '\uf22b'
    MARS_STROKE_UP = '\uf22a'
    MARTINI_GLASS = '\uf57b'
    MARTINI_GLASS_CITRUS = '\uf561'
    MARTINI_GLASS_EMPTY = '\uf000'
    MASK = '\uf6fa'
    MASK_FACE = '\ue1d7'
    MASK_VENTILATOR = '\ue524'
    MASKS_THEATER = '\uf630'
    MATTRESS_PILLOW = '\ue525'
    MAXIMIZE = '\uf31e'
    MEDAL = '\uf5a2'
    MEMORY = '\uf538'
    MENORAH = '\uf676'
    MERCURY = '\uf223'
    MESSAGE = '\uf27a'
    METEOR = '\uf753'
    MICROCHIP = '\uf2db'
    MICROPHONE = '\uf130'
    MICROPHONE_LINES = '\uf3c9'
    MICROPHONE_LINES_SLASH = '\uf539'
    MICROPHONE_SLASH = '\uf131'
    MICROSCOPE = '\uf610'
    MILL_SIGN = '\ue1ed'
    MINIMIZE = '\uf78c'
    MINUS = '\uf068'
    MITTEN = '\uf7b5'
    MOBILE = '\uf3ce'
    MOBILE_BUTTON = '\uf10b'
    MOBILE_RETRO = '\ue527'
    MOBILE_SCREEN = '\uf3cf'
    MOBILE_SCREEN_BUTTON = '\uf3cd'
    MONEY_BILL = '\uf0d6'
    MONEY_BILL_1 = '\uf3d1'
    MONEY_BILL_1_WAVE = '\uf53b'
    MONEY_BILL_TRANSFER = '\ue528'
    MONEY_BILL_TREND_UP = '\ue529'
    MONEY_BILL_WAVE = '\uf53a'
    MONEY_BILL_WHEAT = '\ue52a'
    MONEY_BILLS = '\ue1f3'
    MONEY_CHECK = '\uf53c'
    MONEY_CHECK_DOLLAR = '\uf53d'
    MONUMENT = '\uf5a6'
    MOON = '\uf186'
    MORTAR_PESTLE = '\uf5a7'
    MOSQUE = '\uf678'
    MOSQUITO = '\ue52b'
    MOSQUITO_NET = '\ue52c'
    MOTORCYCLE = '\uf21c'
    MOUND = '\ue52d'
    MOUNTAIN = '\uf6fc'
    MOUNTAIN_CITY = '\ue52e'
    MOUNTAIN_SUN = '\ue52f'
    MUG_HOT = '\uf7b6'
    MUG_SAUCER = '\uf0f4'
    MUSIC = '\uf001'
    N = '\u004e'
    NAIRA_SIGN = '\ue1f6'
    NETWORK_WIRED = '\uf6ff'
    NEUTER = '\uf22c'
    NEWSPAPER = '\uf1ea'
    NOT_EQUAL = '\uf53e'
    NOTDEF = '\ue1fe'
    NOTE_STICKY = '\uf249'
    NOTES_MEDICAL = '\uf481'
    O = '\u004f'
    OBJECT_GROUP = '\uf247'
    OBJECT_UNGROUP = '\uf248'
    OIL_CAN = '\uf613'
    OIL_WELL = '\ue532'
    OM = '\uf679'
    OTTER = '\uf700'
    OUTDENT = '\uf03b'
    P = '\u0050'
    PAGER = '\uf815'
    PAINT_ROLLER = '\uf5aa'
    PAINTBRUSH = '\uf1fc'
    PALETTE = '\uf53f'
    PALLET = '\uf482'
    PANORAMA = '\ue209'
    PAPER_PLANE = '\uf1d8'
    PAPERCLIP = '\uf0c6'
    PARACHUTE_BOX = '\uf4cd'
    PARAGRAPH = '\uf1dd'
    PASSPORT = '\uf5ab'
    PASTE = '\uf0ea'
    PAUSE = '\uf04c'
    PAW = '\uf1b0'
    PEACE = '\uf67c'
    PEN = '\uf304'
    PEN_CLIP = '\uf305'
    PEN_FANCY = '\uf5ac'
    PEN_NIB = '\uf5ad'
    PEN_RULER = '\uf5ae'
    PEN_TO_SQUARE = '\uf044'
    PENCIL = '\uf303'
    PEOPLE_ARROWS = '\ue068'
    PEOPLE_CARRY_BOX = '\uf4ce'
    PEOPLE_GROUP = '\ue533'
    PEOPLE_LINE = '\ue534'
    PEOPLE_PULLING = '\ue535'
    PEOPLE_ROBBERY = '\ue536'
    PEOPLE_ROOF = '\ue537'
    PEPPER_HOT = '\uf816'
    PERCENT = '\u0025'
    PERSON = '\uf183'
    PERSON_ARROW_DOWN_TO_LINE = '\ue538'
    PERSON_ARROW_UP_FROM_LINE = '\ue539'
    PERSON_BIKING = '\uf84a'
    PERSON_BOOTH = '\uf756'
    PERSON_BREASTFEEDING = '\ue53a'
    PERSON_BURST = '\ue53b'
    PERSON_CANE = '\ue53c'
    PERSON_CHALKBOARD = '\ue53d'
    PERSON_CIRCLE_CHECK = '\ue53e'
    PERSON_CIRCLE_EXCLAMATION = '\ue53f'
    PERSON_CIRCLE_MINUS = '\ue540'
    PERSON_CIRCLE_PLUS = '\ue541'
    PERSON_CIRCLE_QUESTION = '\ue542'
    PERSON_CIRCLE_XMARK = '\ue543'
    PERSON_DIGGING = '\uf85e'
    PERSON_DOTS_FROM_LINE = '\uf470'
    PERSON_DRESS = '\uf182'
    PERSON_DRESS_BURST = '\ue544'
    PERSON_DROWNING = '\ue545'
    PERSON_FALLING = '\ue546'
    PERSON_FALLING_BURST = '\ue547'
    PERSON_HALF_DRESS = '\ue548'
    PERSON_HARASSING = '\ue549'
    PERSON_HIKING = '\uf6ec'
    PERSON_MILITARY_POINTING = '\ue54a'
    PERSON_MILITARY_RIFLE = '\ue54b'
    PERSON_MILITARY_TO_PERSON = '\ue54c'
    PERSON_PRAYING = '\uf683'
    PERSON_PREGNANT = '\ue31e'
    PERSON_RAYS = '\ue54d'
    PERSON_RIFLE = '\ue54e'
    PERSON_RUNNING = '\uf70c'
    PERSON_SHELTER = '\ue54f'
    PERSON_SKATING = '\uf7c5'
    PERSON_SKIING = '\uf7c9'
    PERSON_SKIING_NORDIC = '\uf7ca'
    PERSON_SNOWBOARDING = '\uf7ce'
    PERSON_SWIMMING = '\uf5c4'
    PERSON_THROUGH_WINDOW = '\ue5a9'
    PERSON_WALKING = '\uf554'
    PERSON_WALKING_ARROW_LOOP_LEFT = '\ue551'
    PERSON_WALKING_ARROW_RIGHT = '\ue552'
    PERSON_WALKING_DASHED_LINE_ARROW_RIGHT = '\ue553'
    PERSON_WALKING_LUGGAGE = '\ue554'
    PERSON_WALKING_WITH_CANE = '\uf29d'
    PESETA_SIGN = '\ue221'
    PESO_SIGN = '\ue222'
    PHONE = '\uf095'
    PHONE_FLIP = '\uf879'
    PHONE_SLASH = '\uf3dd'
    PHONE_VOLUME = '\uf2a0'
    PHOTO_FILM = '\uf87c'
    PIGGY_BANK = '\uf4d3'
    PILLS = '\uf484'
    PIZZA_SLICE = '\uf818'
    PLACE_OF_WORSHIP = '\uf67f'
    PLANE = '\uf072'
    PLANE_ARRIVAL = '\uf5af'
    PLANE_CIRCLE_CHECK = '\ue555'
    PLANE_CIRCLE_EXCLAMATION = '\ue556'
    PLANE_CIRCLE_XMARK = '\ue557'
    PLANE_DEPARTURE = '\uf5b0'
    PLANE_LOCK = '\ue558'
    PLANE_SLASH = '\ue069'
    PLANE_UP = '\ue22d'
    PLANT_WILT = '\ue5aa'
    PLATE_WHEAT = '\ue55a'
    PLAY = '\uf04b'
    PLUG = '\uf1e6'
    PLUG_CIRCLE_BOLT = '\ue55b'
    PLUG_CIRCLE_CHECK = '\ue55c'
    PLUG_CIRCLE_EXCLAMATION = '\ue55d'
    PLUG_CIRCLE_MINUS = '\ue55e'
    PLUG_CIRCLE_PLUS = '\ue55f'
    PLUG_CIRCLE_XMARK = '\ue560'
    PLUS = '\u002b'
    PLUS_MINUS = '\ue43c'
    PODCAST = '\uf2ce'
    POO = '\uf2fe'
    POO_STORM = '\uf75a'
    POOP = '\uf619'
    POWER_OFF = '\uf011'
    PRESCRIPTION = '\uf5b1'
    PRESCRIPTION_BOTTLE = '\uf485'
    PRESCRIPTION_BOTTLE_MEDICAL = '\uf486'
    PRINT = '\uf02f'
    PUMP_MEDICAL = '\ue06a'
    PUMP_SOAP = '\ue06b'
    PUZZLE_PIECE = '\uf12e'
    Q = '\u0051'
    QRCODE = '\uf029'
    QUESTION = '\u003f'
    QUOTE_LEFT = '\uf10d'
    QUOTE_RIGHT = '\uf10e'
    R = '\u0052'
    RADIATION = '\uf7b9'
    RADIO = '\uf8d7'
    RAINBOW = '\uf75b'
    RANKING_STAR = '\ue561'
    RECEIPT = '\uf543'
    RECORD_VINYL = '\uf8d9'
    RECTANGLE_AD = '\uf641'
    RECTANGLE_LIST = '\uf022'
    RECTANGLE_XMARK = '\uf410'
    RECYCLE = '\uf1b8'
    REGISTERED = '\uf25d'
    REPEAT = '\uf363'
    REPLY = '\uf3e5'
    REPLY_ALL = '\uf122'
    REPUBLICAN = '\uf75e'
    RESTROOM = '\uf7bd'
    RETWEET = '\uf079'
    RIBBON = '\uf4d6'
    RIGHT_FROM_BRACKET = '\uf2f5'
    RIGHT_LEFT = '\uf362'
    RIGHT_LONG = '\uf30b'
    RIGHT_TO_BRACKET = '\uf2f6'
    RING = '\uf70b'
    ROAD = '\uf018'
    ROAD_BARRIER = '\ue562'
    ROAD_BRIDGE = '\ue563'
    ROAD_CIRCLE_CHECK = '\ue564'
    ROAD_CIRCLE_EXCLAMATION = '\ue565'
    ROAD_CIRCLE_XMARK = '\ue566'
    ROAD_LOCK = '\ue567'
    ROAD_SPIKES = '\ue568'
    ROBOT = '\uf544'
    ROCKET = '\uf135'
    ROTATE = '\uf2f1'
    ROTATE_LEFT = '\uf2ea'
    ROTATE_RIGHT = '\uf2f9'
    ROUTE = '\uf4d7'
    RSS = '\uf09e'
    RUBLE_SIGN = '\uf158'
    RUG = '\ue569'
    RULER = '\uf545'
    RULER_COMBINED = '\uf546'
    RULER_HORIZONTAL = '\uf547'
    RULER_VERTICAL = '\uf548'
    RUPEE_SIGN = '\uf156'
    RUPIAH_SIGN = '\ue23d'
    S = '\u0053'
    SACK_DOLLAR = '\uf81d'
    SACK_XMARK = '\ue56a'
    SAILBOAT = '\ue445'
    SATELLITE = '\uf7bf'
    SATELLITE_DISH = '\uf7c0'
    SCALE_BALANCED = '\uf24e'
    SCALE_UNBALANCED = '\uf515'
    SCALE_UNBALANCED_FLIP = '\uf516'
    SCHOOL = '\uf549'
    SCHOOL_CIRCLE_CHECK = '\ue56b'
    SCHOOL_CIRCLE_EXCLAMATION = '\ue56c'
    SCHOOL_CIRCLE_XMARK = '\ue56d'
    SCHOOL_FLAG = '\ue56e'
    SCHOOL_LOCK = '\ue56f'
    SCISSORS = '\uf0c4'
    SCREWDRIVER = '\uf54a'
    SCREWDRIVER_WRENCH = '\uf7d9'
    SCROLL = '\uf70e'
    SCROLL_TORAH = '\uf6a0'
    SD_CARD = '\uf7c2'
    SECTION = '\ue447'
    SEEDLING = '\uf4d8'
    SERVER = '\uf233'
    SHAPES = '\uf61f'
    SHARE = '\uf064'
    SHARE_FROM_SQUARE = '\uf14d'
    SHARE_NODES = '\uf1e0'
    SHEET_PLASTIC = '\ue571'
    SHEKEL_SIGN = '\uf20b'
    SHIELD = '\uf132'
    SHIELD_CAT = '\ue572'
    SHIELD_DOG = '\ue573'
    SHIELD_HALVED = '\uf3ed'
    SHIELD_HEART = '\ue574'
    SHIELD_VIRUS = '\ue06c'
    SHIP = '\uf21a'
    SHIRT = '\uf553'
    SHOE_PRINTS = '\uf54b'
    SHOP = '\uf54f'
    SHOP_LOCK = '\ue4a5'
    SHOP_SLASH = '\ue070'
    SHOWER = '\uf2cc'
    SHRIMP = '\ue448'
    SHUFFLE = '\uf074'
    SHUTTLE_SPACE = '\uf197'
    SIGN_HANGING = '\uf4d9'
    SIGNAL = '\uf012'
    SIGNATURE = '\uf5b7'
    SIGNS_POST = '\uf277'
    SIM_CARD = '\uf7c4'
    SINK = '\ue06d'
    SITEMAP = '\uf0e8'
    SKULL = '\uf54c'
    SKULL_CROSSBONES = '\uf714'
    SLASH = '\uf715'
    SLEIGH = '\uf7cc'
    SLIDERS = '\uf1de'
    SMOG = '\uf75f'
    SMOKING = '\uf48d'
    SNOWFLAKE = '\uf2dc'
    SNOWMAN = '\uf7d0'
    SNOWPLOW = '\uf7d2'
    SOAP = '\ue06e'
    SOCKS = '\uf696'
    SOLAR_PANEL = '\uf5ba'
    SORT = '\uf0dc'
    SORT_DOWN = '\uf0dd'
    SORT_UP = '\uf0de'
    SPA = '\uf5bb'
    SPAGHETTI_MONSTER_FLYING = '\uf67b'
    SPELL_CHECK = '\uf891'
    SPIDER = '\uf717'
    SPINNER = '\uf110'
    SPLOTCH = '\uf5bc'
    SPOON = '\uf2e5'
    SPRAY_CAN = '\uf5bd'
    SPRAY_CAN_SPARKLES = '\uf5d0'
    SQUARE = '\uf0c8'
    SQUARE_ARROW_UP_RIGHT = '\uf14c'
    SQUARE_CARET_DOWN = '\uf150'
    SQUARE_CARET_LEFT = '\uf191'
    SQUARE_CARET_RIGHT = '\uf152'
    SQUARE_CARET_UP = '\uf151'
    SQUARE_CHECK = '\uf14a'
    SQUARE_ENVELOPE = '\uf199'
    SQUARE_FULL = '\uf45c'
    SQUARE_H = '\uf0fd'
    SQUARE_MINUS = '\uf146'
    SQUARE_NFI = '\ue576'
    SQUARE_PARKING = '\uf540'
    SQUARE_PEN = '\uf14b'
    SQUARE_PERSON_CONFINED = '\ue577'
    SQUARE_PHONE = '\uf098'
    SQUARE_PHONE_FLIP = '\uf87b'
    SQUARE_PLUS = '\uf0fe'
    SQUARE_POLL_HORIZONTAL = '\uf682'
    SQUARE_POLL_VERTICAL = '\uf681'
    SQUARE_ROOT_VARIABLE = '\uf698'
    SQUARE_RSS = '\uf143'
    SQUARE_SHARE_NODES = '\uf1e1'
    SQUARE_UP_RIGHT = '\uf360'
    SQUARE_VIRUS = '\ue578'
    SQUARE_XMARK = '\uf2d3'
    STAFF_SNAKE = '\ue579'
    STAIRS = '\ue289'
    STAMP = '\uf5bf'
    STAPLER = '\ue5af'
    STAR = '\uf005'
    STAR_AND_CRESCENT = '\uf699'
    STAR_HALF = '\uf089'
    STAR_HALF_STROKE = '\uf5c0'
    STAR_OF_DAVID = '\uf69a'
    STAR_OF_LIFE = '\uf621'
    STERLING_SIGN = '\uf154'
    STETHOSCOPE = '\uf0f1'
    STOP = '\uf04d'
    STOPWATCH = '\uf2f2'
    STOPWATCH_20 = '\ue06f'
    STORE = '\uf54e'
    STORE_SLASH = '\ue071'
    STREET_VIEW = '\uf21d'
    STRIKETHROUGH = '\uf0cc'
    STROOPWAFEL = '\uf551'
    SUBSCRIPT = '\uf12c'
    SUITCASE = '\uf0f2'
    SUITCASE_MEDICAL = '\uf0fa'
    SUITCASE_ROLLING = '\uf5c1'
    SUN = '\uf185'
    SUN_PLANT_WILT = '\ue57a'
    SUPERSCRIPT = '\uf12b'
    SWATCHBOOK = '\uf5c3'
    SYNAGOGUE = '\uf69b'
    SYRINGE = '\uf48e'
    T = '\u0054'
    TABLE = '\uf0ce'
    TABLE_CELLS = '\uf00a'
    TABLE_CELLS_COLUMN_LOCK = '\ue678'
    TABLE_CELLS_LARGE = '\uf009'
    TABLE_CELLS_ROW_LOCK = '\ue67a'
    TABLE_COLUMNS = '\uf0db'
    TABLE_LIST = '\uf00b'
    TABLE_TENNIS_PADDLE_BALL = '\uf45d'
    TABLET = '\uf3fb'
    TABLET_BUTTON = '\uf10a'
    TABLET_SCREEN_BUTTON = '\uf3fa'
    TABLETS = '\uf490'
    TACHOGRAPH_DIGITAL = '\uf566'
    TAG = '\uf02b'
    TAGS = '\uf02c'
    TAPE = '\uf4db'
    TARP = '\ue57b'
    TARP_DROPLET = '\ue57c'
    TAXI = '\uf1ba'
    TEETH = '\uf62e'
    TEETH_OPEN = '\uf62f'
    TEMPERATURE_ARROW_DOWN = '\ue03f'
    TEMPERATURE_ARROW_UP = '\ue040'
    TEMPERATURE_EMPTY = '\uf2cb'
    TEMPERATURE_FULL = '\uf2c7'
    TEMPERATURE_HALF = '\uf2c9'
    TEMPERATURE_HIGH = '\uf769'
    TEMPERATURE_LOW = '\uf76b'
    TEMPERATURE_QUARTER = '\uf2ca'
    TEMPERATURE_THREE_QUARTERS = '\uf2c8'
    TENGE_SIGN = '\uf7d7'
    TENT = '\ue57d'
    TENT_ARROW_DOWN_TO_LINE = '\ue57e'
    TENT_ARROW_LEFT_RIGHT = '\ue57f'
    TENT_ARROW_TURN_LEFT = '\ue580'
    TENT_ARROWS_DOWN = '\ue581'
    TENTS = '\ue582'
    TERMINAL = '\uf120'
    TEXT_HEIGHT = '\uf034'
    TEXT_SLASH = '\uf87d'
    TEXT_WIDTH = '\uf035'
    THERMOMETER = '\uf491'
    THUMBS_DOWN = '\uf165'
    THUMBS_UP = '\uf164'
    THUMBTACK = '\uf08d'
    TICKET = '\uf145'
    TICKET_SIMPLE = '\uf3ff'
    TIMELINE = '\ue29c'
    TOGGLE_OFF = '\uf204'
    TOGGLE_ON = '\uf205'
    TOILET = '\uf7d8'
    TOILET_PAPER = '\uf71e'
    TOILET_PAPER_SLASH = '\ue072'
    TOILET_PORTABLE = '\ue583'
    TOILETS_PORTABLE = '\ue584'
    TOOLBOX = '\uf552'
    TOOTH = '\uf5c9'
    TORII_GATE = '\uf6a1'
    TORNADO = '\uf76f'
    TOWER_BROADCAST = '\uf519'
    TOWER_CELL = '\ue585'
    TOWER_OBSERVATION = '\ue586'
    TRACTOR = '\uf722'
    TRADEMARK = '\uf25c'
    TRAFFIC_LIGHT = '\uf637'
    TRAILER = '\ue041'
    TRAIN = '\uf238'
    TRAIN_SUBWAY = '\uf239'
    TRAIN_TRAM = '\ue5b4'
    TRANSGENDER = '\uf225'
    TRASH = '\uf1f8'
    TRASH_ARROW_UP = '\uf829'
    TRASH_CAN = '\uf2ed'
    TRASH_CAN_ARROW_UP = '\uf82a'
    TREE = '\uf1bb'
    TREE_CITY = '\ue587'
    TRIANGLE_EXCLAMATION = '\uf071'
    TROPHY = '\uf091'
    TROWEL = '\ue589'
    TROWEL_BRICKS = '\ue58a'
    TRUCK = '\uf0d1'
    TRUCK_ARROW_RIGHT = '\ue58b'
    TRUCK_DROPLET = '\ue58c'
    TRUCK_FAST = '\uf48b'
    TRUCK_FIELD = '\ue58d'
    TRUCK_FIELD_UN = '\ue58e'
    TRUCK_FRONT = '\ue2b7'
    TRUCK_MEDICAL = '\uf0f9'
    TRUCK_MONSTER = '\uf63b'
    TRUCK_MOVING = '\uf4df'
    TRUCK_PICKUP = '\uf63c'
    TRUCK_PLANE = '\ue58f'
    TRUCK_RAMP_BOX = '\uf4de'
    TTY = '\uf1e4'
    TURKISH_LIRA_SIGN = '\ue2bb'
    TURN_DOWN = '\uf3be'
    TURN_UP = '\uf3bf'
    TV = '\uf26c'
    U = '\u0055'
    UMBRELLA = '\uf0e9'
    UMBRELLA_BEACH = '\uf5ca'
    UNDERLINE = '\uf0cd'
    UNIVERSAL_ACCESS = '\uf29a'
    UNLOCK = '\uf09c'
    UNLOCK_KEYHOLE = '\uf13e'
    UP_DOWN = '\uf338'
    UP_DOWN_LEFT_RIGHT = '\uf0b2'
    UP_LONG = '\uf30c'
    UP_RIGHT_AND_DOWN_LEFT_FROM_CENTER = '\uf424'
    UP_RIGHT_FROM_SQUARE = '\uf35d'
    UPLOAD = '\uf093'
    USER = '\uf007'
    USER_ASTRONAUT = '\uf4fb'
    USER_CHECK = '\uf4fc'
    USER_CLOCK = '\uf4fd'
    USER_DOCTOR = '\uf0f0'
    USER_GEAR = '\uf4fe'
    USER_GRADUATE = '\uf501'
    USER_GROUP = '\uf500'
    USER_INJURED = '\uf728'
    USER_LARGE = '\uf406'
    USER_LARGE_SLASH = '\uf4fa'
    USER_LOCK = '\uf502'
    USER_MINUS = '\uf503'
    USER_NINJA = '\uf504'
    USER_NURSE = '\uf82f'
    USER_PEN = '\uf4ff'
    USER_PLUS = '\uf234'
    USER_SECRET = '\uf21b'
    USER_SHIELD = '\uf505'
    USER_SLASH = '\uf506'
    USER_TAG = '\uf507'
    USER_TIE = '\uf508'
    USER_XMARK = '\uf235'
    USERS = '\uf0c0'
    USERS_BETWEEN_LINES = '\ue591'
    USERS_GEAR = '\uf509'
    USERS_LINE = '\ue592'
    USERS_RAYS = '\ue593'
    USERS_RECTANGLE = '\ue594'
    USERS_SLASH = '\ue073'
    USERS_VIEWFINDER = '\ue595'
    UTENSILS = '\uf2e7'
    V = '\u0056'
    VAN_SHUTTLE = '\uf5b6'
    VAULT = '\ue2c5'
    VECTOR_SQUARE = '\uf5cb'
    VENUS = '\uf221'
    VENUS_DOUBLE = '\uf226'
    VENUS_MARS = '\uf228'
    VEST = '\ue085'
    VEST_PATCHES = '\ue086'
    VIAL = '\uf492'
    VIAL_CIRCLE_CHECK = '\ue596'
    VIAL_VIRUS = '\ue597'
    VIALS = '\uf493'
    VIDEO = '\uf03d'
    VIDEO_SLASH = '\uf4e2'
    VIHARA = '\uf6a7'
    VIRUS = '\ue074'
    VIRUS_COVID = '\ue4a8'
    VIRUS_COVID_SLASH = '\ue4a9'
    VIRUS_SLASH = '\ue075'
    VIRUSES = '\ue076'
    VOICEMAIL = '\uf897'
    VOLCANO = '\uf770'
    VOLLEYBALL = '\uf45f'
    VOLUME_HIGH = '\uf028'
    VOLUME_LOW = '\uf027'
    VOLUME_OFF = '\uf026'
    VOLUME_XMARK = '\uf6a9'
    VR_CARDBOARD = '\uf729'
    W = '\u0057'
    WALKIE_TALKIE = '\uf8ef'
    WALLET = '\uf555'
    WAND_MAGIC = '\uf0d0'
    WAND_MAGIC_SPARKLES = '\ue2ca'
    WAND_SPARKLES = '\uf72b'
    WAREHOUSE = '\uf494'
    WATER = '\uf773'
    WATER_LADDER = '\uf5c5'
    WAVE_SQUARE = '\uf83e'
    WEIGHT_HANGING = '\uf5cd'
    WEIGHT_SCALE = '\uf496'
    WHEAT_AWN = '\ue2cd'
    WHEAT_AWN_CIRCLE_EXCLAMATION = '\ue598'
    WHEELCHAIR = '\uf193'
    WHEELCHAIR_MOVE = '\ue2ce'
    WHISKEY_GLASS = '\uf7a0'
    WIFI = '\uf1eb'
    WIND = '\uf72e'
    WINDOW_MAXIMIZE = '\uf2d0'
    WINDOW_MINIMIZE = '\uf2d1'
    WINDOW_RESTORE = '\uf2d2'
    WINE_BOTTLE = '\uf72f'
    WINE_GLASS = '\uf4e3'
    WINE_GLASS_EMPTY = '\uf5ce'
    WON_SIGN = '\uf159'
    WORM = '\ue599'
    WRENCH = '\uf0ad'
    X = '\u0058'
    X_RAY = '\uf497'
    XMARK = '\uf00d'
    XMARKS_LINES = '\ue59a'
    Y = '\u0059'
    YEN_SIGN = '\uf157'
    YIN_YANG = '\uf6ad'
    Z = '\u005a'
